********************************************************************************
********************************************************************************
*Frisch Elasticity of Labor Supply at the Extensive Margin - Meta-Analysis
********************************************************************************
********************************************************************************

*log using frisch.log, replace
*set more off

*ssc install ivreg2, replace
*ssc install estout
*ssc install winsor2
*ssc install ranktest
*ssc install outreg2
*ssc install boottest

********************************************************************************
* Re-sampling stderrors - BOOTSTRAPPING
********************************************************************************
use frisch_data.dta, replace
generate frisch_boot = frisch
save frisch_data_boot.dta, replace

summarize idstudy
local boots = r(max)
*local boots = 2
local reps = 1000

***generating blank dataset for storage
clear
set obs `boots'
generate idstudy = .
generate store_means = .
generate original_means = .
generate store_stdevs = .

*making output quietly
quietly{
	*bootstrapping for each study in the panel
	forvalues i = 1(1) `boots' {
		*preserving generated storage dataset
		preserve
		
		use frisch_boot idstudy using frisch_data_boot.dta, clear
		
		*adding counter and display noisily
		if floor((`i'-1)/1) == (`i'-1)/1 {
			noisily display "Worknig on `i' out of `boots' at $S_TIME"
		}
		*keep the data for i-th study only
		keep if idstudy==`i'
		
		*storing mean coefficient of original data
		summarize frisch_boot
		local mean_frisch_orig = r(mean)
	
		*tempfile boot_study_`i'

		*actual bootstrapping
		*bsample
		bootstrap mean=r(mean), reps(`reps') strata(idstudy) seed(1234) saving(boot_study_`i', replace): summarize frisch_boot, detail
		*estat bootstrap, all
		*so the problem is that the bootstrapped command does not pass the stored result from r(mean)-probably it even does not do so...		
		use boot_study_`i', replace
		summarize mean
		*storing into local macro
		local mean_frisch = r(mean)
		local mean_frisch_sd = r(sd)		
		
		*restoring generated storage dataset
		restore
		
		replace idstudy = `i' in `i'
		
		display "replacing store_means = `mean_frisch' in `i'"	
		replace store_means = `mean_frisch' in `i'
		display "replacing original_means = `mean_frisch_orig' in `i'"
		replace original_means = `mean_frisch_orig' in `i'
		display "replacing store_stdevs = `mean_frisch_sd' in `i'"
		replace store_stdevs = `mean_frisch_sd' in `i'
	}
}
*saving bootstrapped results
save boot_results.dta, replace

*merge and store
use frisch_data_boot.dta, replace
merge m:1 idstudy using boot_results.dta

drop _merge store_means frisch_boot
rename original_means study_mean
rename store_stdevs study_se

save frisch_data_boot.dta, replace

use frisch_data_boot.dta, replace

********************************************************************************
*VARIABLES 
********************************************************************************
gen nusa=.
replace nusa=1 if usa==0
replace nusa=0 if usa==1

*Generating new variables from original SEs
replace se=0.001 if se==0 
gen prec = 1/se
gen prec2 = 1/(se*se)
gen lnprec = ln(prec)
gen tstat = frisch/se
gen invperstudy = 1/est_per_study
gen lnpubyear = ln(pub_year_dif)
gen lnobs = ln(no_obs)
gen invobs = 1/no_obs
gen invsqrtnobs = 1/sqrt(no_obs)
gen sqrtnobs = sqrt(no_obs)
gen lnycite=ln(ln_cite +1)

*Winsorizing original variables
winsor2 frisch se, suffix(_win) cuts(5 95) label
winsor2 invsqrtnobs, suffix(_win) cuts(5 95) label
gen tstat_win = frisch_win/se_win
gen prec_win = 1/se_win
gen prec2_win = 1/(se_win*se_win)

*winsor2 frisch se, suffix(_win99) cuts(1 99) label

*Combining bootstrapped and reported sandard errors
gen se_comb = .
replace se_comb = se if se != .
replace se_comb = study_se if se == .

*Generating variables from combined SEs
replace se_comb=0.001 if se_comb==0 
gen prec_comb = 1/se_comb
gen prec2_comb = 1/(se_comb*se_comb)
gen tstat_comb = frisch/se_comb
gen lnprec_comb = ln(prec_comb)

*Winsorizing variables from combined SEs
winsor2 se_comb, suffix(_win) cuts(5 95) label
gen se2_comb_win = se_comb_win*se_comb_win
gen tstat_comb_win = frisch_win/se_comb_win
gen prec_comb_win = 1/se_comb_win
gen prec2_comb_win = 1/(se_comb_win*se_comb_win)

*************************** SUMMARY STATISTICS *********************************
********************************************************************************
sum frisch se prime nearretirement female male married single income ln_timespan monthly quarterly industry macro usa indivlab quasi probit nonpar_sim sls_iv lnpubyear top lnycite cite_google byproduct
sum frisch, detail
return list
gen fmean = r(mean)
gen fmed= r(p50)

sum frisch frisch_win se se_win se_comb_win se_comb

estpost sum frisch se se_comb

esttab using sum.tex, replace title(Summary Statistics /// \
	\label{tab: sum}) cells("count sum_w mean Var sd min max sum") /// \
	addnote("SE Combined = Standard errors re-sampled from bootstrapping.") /// \
	/// \
	label nonumber width(1\\hsize)
eststo clear

*Different frequencies
*monthly has the highest mean
sum frisch if daily==1
gen damean = r(mean)
sum frisch if monthly==1
gen momean = r(mean)
sum frisch if quarterly==1
gen qumean = r(mean)
sum frisch if annual==1
gen anmean = r(mean)

*usa > others	  	    
sum frisch if usa==1
gen usmean = r(mean) 
sum frisch if usa==0 
gen nusmean = r(mean)

*female > male
sum frisch if male==1
gen mamean = r(mean)
sum frisch if female==1
gen femean = r(mean)
sum frisch if female==0 & male==0 
sum frisch if malefemale==1

*quasi exp < others
sum frisch if quasi_exp==1
gen quasmean = r(mean)
sum frisch if quasi_exp==0
gen nquasmean = r(mean)

*macro > micro
sum frisch if macro==1
gen macmean = r(mean) 
sum frisch if micro==1
gen micmean = r(mean) 

*indivisible labor
sum frisch if indivlab==1
sum frisch if indivlab==0

*interesting top > nontop 
sum frisch if top==1
sum frisch if top==0

*simulation based and parametric
sum frisch if nonpar_sim==1
sum frisch if nonpar_sim==0

sum frisch if published==1
sum frisch if published==0

*prime-age and near to retirment groups
sum frisch if prime==1
gen prmean= r(mean)
sum frisch if nearretirement==1
gen nrmean= r(mean)
sum frisch if  prime==0 & nearretirement==0
gen almean= r(mean)
sum frisch if prime==0
gen nprmean = r(mean)

********************************************************************************
*Plots and graphs
********************************************************************************

*Boxplot of all studies
graph hbox frisch  if frisch<3 & frisch>-2 , over(paper, sort(pub_year)) ytitle("Estimated elasticities") xsize(10) ysize(12) scale(0.6) graphregion(color(white)) saving(_box2, replace)
*saving plot
graph use _box2
graph export _box2.pdf, replace

*Trend of the mean elasticity of papers and the year of publication
graph twoway (scatter study_mean pub_year, msize(*1) ytitle("Mean value of estimated elasticity in a study") xtitle("Publication year") graphregion(color(white)) legend(off))(lfit study_mean pub_year, lcolor(black)), saving(_trend, replace)
*saving plot
graph use _trend
graph export _trend.pdf, replace


*Trend of the mean elasticity of papers and the duration of used data
graph twoway (scatter study_mean timespan, msize(*1) ytitle("Elasticity") xtitle("Timespan") legend(off))(lfit study_mean timespan, lcolor(black)), saving(_span, replace)
*saving plot
graph use _span
graph export _span.pdf, replace


*Histogram of all estimated elasticities 
local m1 = fmean
local m2 = fmed
hist frisch if  frisch >-1 & frisch <3  , width(0.1) xlabel(-1(0.5)3) start(-1) fcolor(navy*.4) lcolor(navy*.5) width(0.1)  frequency xtitle("Estimated elasticity") ///
xlabel(, format(%9.1f)) saving(_hist_frisch, replace) graphregion(color(white)) legend(off) /// 
addplot (scatteri 0 `m1' 150 `m1', color (black) c(1) m(i) || scatteri 0 `m2' 150 `m2', color (black) lpattern(dash) c(1) m(i))
*saving plot
graph use _hist_frisch
graph export _hist_frisch.pdf, replace


*Comparative histograms

local m1 = nusmean
local m2 = usmean
twoway (hist frisch if usa==1  & frisch<3 & frisch>-1, freq color(dknavy)  xtitle("Estimated elasticities") ytitle("Frequency"))  ///
(hist frisch if usa==0 & frisch<3 & frisch>-1, freq  color(gs12)) (scatteri 0 `m2' 150 `m2', color (black) c(1) m(i)) (scatteri 0 `m1' 150 `m1', color (black) lpattern(dash) c(1) m(i))(scatteri  150 `m1' (9) "0.32", mlabcolor (black) msymbol(none)) (scatteri 150 `m2' (3) "0.58", mlabcolor (black) msymbol(none)),  ///
xlabel(, format(%9.0f)) graphregion(color(white)) legend(order(2 "Non-US data" 1 "US data")) saving(_new_hist_usnonus, replace)
*saving plot
graph use _new_hist_usnonus
graph export _new_hist_usnonus.pdf, replace



local m1 = mamean
local m2 = femean
twoway (hist frisch if male==1 & frisch<3 & frisch>-1, freq  color(gs12) xtitle("Estimated elasticities") ytitle("Frequency"))  ///
(hist frisch if female==1  & frisch<3 & frisch>-1, freq color(dknavy)) (scatteri 0 `m2' 80 `m2', color (black) c(1) m(i)) (scatteri 0 `m1' 80 `m1', color (black) lpattern(dash) c(1) m(i))(scatteri  80 `m1' (9) "0.41", mlabcolor (black) msymbol(none)) (scatteri 80 `m2' (3) "0.56", mlabcolor (black) msymbol(none)),  ///
xlabel(, format(%9.0f)) graphregion(color(white)) legend(order(1 "Male" 2 "Female")) saving(_new_hist_mafemean, replace)
*saving plot
graph use _new_hist_mafemean
graph export _new_hist_mafemean.pdf, replace



local m1 = micmean
local m2 = macmean
twoway (hist frisch if micro==1  & frisch<3 & frisch>-1, freq  color(gs12)  xtitle("Estimated elasticities") ytitle("Frequency")) ///
(hist frisch if macro==1 & frisch<3 & frisch>-1, freq   color(dknavy)) (scatteri 0 `m2' 150 `m2', color (black) c(1) m(i)) (scatteri 0 `m1' 150 `m1', color (black) lpattern(dash) c(1) m(i)) (scatteri  150 `m1' (9) "0.41", mlabcolor (black) msymbol(none)) (scatteri 150 `m2' (3) "0.71", mlabcolor (black) msymbol(none)), ///
 xlabel(, format(%9.0f)) graphregion(color(white)) legend(order(1 "Micro" 2 "Macro")) saving(_new_hist_micmac, replace)
*saving plot
graph use _new_hist_micmac
graph export _new_hist_micmac.pdf, replace



local m1 = nmicquasmean
local m2 = quasmean
twoway (hist frisch if quasi_exp==0 & frisch<3 & frisch>-1, freq  color(dknavy) xtitle("Estimated elasticities") ytitle("Frequency")) ///
(hist frisch if quasi_exp==1 & micro==1 & frisch<3 & frisch>-1, freq  color(gs12))(scatteri 0 `m1' 150 `m1', color (black)  c(1) m(i)) (scatteri 0 `m2' 150 `m2', color (black) lpattern(dash) c(1) m(i)) (scatteri  150 `m1' (3) "0.51", mlabcolor (black) msymbol(none)) (scatteri 150 `m2' (9) "0.22",  mlabcolor (black) msymbol(none)), ///
xlabel(, format(%9.0f))  graphregion(color(white)) legend(order(2 "Quasi-experiment" 1 "Micro non quasi-experiment")) saving(_new_hist_quasi, replace)
*saving plot
graph use _new_hist_quasi
graph export _new_hist_quasi.pdf, replace



local m1 = nrmean
local m2 = prmean
twoway (hist frisch if prime==1 & frisch<2 & frisch>-1, freq  color(gs12) xtitle("Estimated elasticities") ytitle("Frequency")) ///
(hist frisch if nearretirement==1 & frisch<4 & frisch>-1, freq  color(dknavy))(scatteri 0 `m1' 50 `m1', color (black)  c(1) m(i)) (scatteri 0 `m2' 50 `m2', color (black) lpattern(dash) c(1) m(i)) (scatteri  50 `m1' (3) "0.52", mlabcolor (black) msymbol(none)) (scatteri 50 `m2' (9) "0.40",  mlabcolor (black) msymbol(none)), ///
xlabel(, format(%9.0f))  graphregion(color(white)) legend(order(1 "Prime age" 2 "Near retirement")) saving(_new_hist_prime50, replace)
*saving plot
graph use _new_hist_prime50
graph export _new_hist_prime50.pdf, replace

********************************PUBLICATION BIAS********************************
********************************************************************************

*Funnel plot of all estimates - Egger et al., 1997
scatter prec_comb frisch if frisch<9 & frisch>-1 &  prec<100  , msize(*.6) msymbol(O)  xlabel(-2(1)4) ///
xtitle("Elasticity") ///
ytitle("Precision of estimates, (1/SE)") ///
legend(off) graphregion(color(white)) saving(_funnel_all, replace) 
*saving plot
graph use _funnel_all
graph export _funnel_all.pdf, replace


scatter prec_comb frisch if frisch<9 & frisch>-1 &  prec<100  & frisch!=2.39 & frisch!=2.41 , msize(*.6) msymbol(O)  xlabel(-2(1)4) ///
xtitle("Elasticity") ///
ytitle("Precision of estimates, (1/SE)") ///
legend(off) graphregion(color(white)) saving(_funnel_all2, replace) 
*saving plot
graph use _funnel_all2
graph export _funnel_all2.pdf, replace


/*T-stat plot
graph twoway (hist tstat if tstat <20 & tstat>-5, width(0.5) xlabel(0(5)18) ///
ytitle("Density") ///
xtitle("Reported t-statistics")) ///
, saving(hist_tstat, replace)
*/


*T-stat plot
sum tstat_comb if tstat_comb <25 & tstat_comb>-5
gen tsmean = r(mean)
local m =  8.366532 
graph twoway (hist tstat_comb if tstat_comb <25 & tstat_comb>-5, width(0.5) xlabel(0(5)20) ytitle("Density") ///
xtitle("Reported t-statistics") legend(off)) ///
(scatteri 0 `m' .15 `m', color (black) c(1) m(i)) ///
, saving(_hist_tstat, replace)
*saving plot
graph export _hist_tstat.pdf, replace

********************************************************************************
*FUNNEL ASYMMETRY TESTS - Publication bias 
********************************************************************************
*data to panel
xtset idstudy

***PET - SE Combined
*OLS regresssion, non-weighted, clustered on study level only
eststo: ivreg2 frisch_win se_comb_win, cluster(idstudy)
boottest se_comb_win
boottest _cons

*FE regresssion, clustered on study level only
eststo: xtreg frisch_win se_comb_win, fe

*BE regresssion
eststo: xtreg frisch_win se_comb_win, be

*Precision, p-weighted by winsorized combined 1/SE, clustered on study level only
eststo: ivreg2 frisch_win se_comb_win [pweight=prec_comb_win], cluster(idstudy)
boottest se_comb_win
boottest _cons

*Study, p-weighted by inverse of number per study estimates, clustered on study level only 
eststo: ivreg2 frisch_win se_comb_win [pweight=invperstudy], cluster(idstudy)
boottest se_comb_win
boottest _cons

*IV regression
eststo: ivreg2 frisch_win (se_win=invsqrtnobs_win) [pweight=invperstudy*prec_win]

*saving PET tests
esttab using PET.tex, replace se title(Linear funnel asymmetry tests - PET /// \
	\label{tab: PET}) mtitles("OLS" "FE" "BE" "Precision" "Study" "IV" ) /// \
	///addnote("Standard errors are clustered at the study level.") /// \
	star(\sym{*} 0.10 \sym{**} 0.05 \sym{***} 0.01) /// \
	label nonumber width(1\\hsize)
eststo clear

***PET - SE
*OLS regresssion, non-weighted, clustered on study level only
eststo: ivreg2 frisch_win se_win, cluster(idstudy)
boottest se_win
boottest _cons

*FE regresssion, clustered on study level only
eststo: xtreg frisch_win se_win, fe cluster(idstudy)

*BE regresssion
eststo: xtreg frisch_win se_win, be

*Precision, p-weighted by winsorized combined 1/SE, clustered on study level only
eststo: ivreg2 frisch_win se_win [pweight=prec_win], cluster(idstudy)
boottest se_win
boottest _cons

*Study, p-weighted by inverse of number per study estimates, clustered on study level only 
eststo: ivreg2 frisch_win se_win [pweight=invperstudy], cluster(idstudy)
boottest se_win
boottest _cons

*saving PET tests
esttab using PETnon.tex, replace se title(Linear funnel asymmetry tests - PET /// \
	\label{tab: PETnon}) mtitles("OLS" "FE" "BE" "IV" "Precision" "Study") /// \
	///addnote("Standard errors are clustered at the study level.") /// \
	star(\sym{*} 0.10 \sym{**} 0.05 \sym{***} 0.01) /// \
	label nonumber width(1\\hsize)
eststo clear

********************************************************************************
*Non-linear techniques - Publication bias
********************************************************************************

*TOP 10 method - Stanley et al. 2010
summarize prec_comb, detail
local top10bound1 = r(p90)
summarize frisch prec_comb if prec_comb > `top10bound1'

summarize prec if prec!=., detail
local top10bound2 = r(p90)
summarize frisch prec if prec > `top10bound2' & prec!=.

*WAAP - Ioaninidis et al. 2017
reg tstat_comb_win prec_comb_win, noconstant
reg tstat_comb_win prec_comb_win if se<.2636283 /2.8, noconstant cluster(idstudy)

reg tstat_win prec_win, noconstant
reg tstat_win prec_win if se<0.2502997 /2.8, noconstant cluster(idstudy)


*Andrews & Kasy 2019
*https://maxkasy.github.io/home/metastudy

outsheet frisch_win se_comb_win idstudy using ak-secomb.csv, comma replace

*SE Combined: 	            μ	    τ	   df	[0, 1.96 ]
*            estimate	0.356	0.182	2.794	1.450
*            se	        0.061	0.013	0.312	0.212


outsheet frisch_win se_win if se_win!=. using ak-se.csv, comma replace 

*SE:         	            μ	    τ	   df	[0, 1.96 ]
*            estimate	0.331	0.148	3.608	1.798
*            se	        0.009	0.009	0.559	0.323

log off

*Endogenous kink - Bom & Rachinger 2019

*SE Combined:
quietly {
clear 
import excel "ek-secomb.xlsx"
rename A bs
rename B sebs


log using kink_se_comb.log, text replace
 
gen ones=1
   
sum
local M=r(N)
sum sebs
local sebs_min=r(min)
local sebs_max=r(max)
  
gen sebs2=sebs^2
gen wis=ones/sebs2
gen bs_sebs=bs/sebs
gen ones_sebs=ones/sebs

gen bswis=bs*wis
sum wis
local wis_sum=r(sum)


* FAT-PET
regress bs_sebs ones_sebs ones,noc
local pet=_b[ones_sebs]
local t1_linreg = (_b[ones_sebs]/_se[ones_sebs])
local b_lin=_b[ones_sebs]
local Q1_lin = e(rss)
di `t1_linreg'
local abs_t1_linreg = abs(`t1_linreg')
di `abs_t1_linreg'


* PEESE
regress bs_sebs ones_sebs sebs,noc
local peese=_b[ones_sebs]
local b_sq=_b[ones_sebs]
local Q1_sq = e(rss)
di `Q1_sq'
 

* FAT-PET-PEESE

if `abs_t1_linreg' > invt(`M-2', 0.975) {
    local combreg=`b_sq'
	local Q1=`Q1_sq'
	}
else {
    local combreg=`b_lin'
	local Q1=`Q1_lin'
}

* estimation of random effects variance component
local sigh2hat=max(0,`M'*((`Q1'/(`M'-e(df_m)-1))-1)/`wis_sum') 
local sighhat=sqrt(`sigh2hat') 


* Cutoff value for EK
if `combreg'>1.96*`sighhat' {
    local a1=(`combreg'-1.96*`sighhat')*(`combreg'+1.96*`sighhat')/(2*1.96*`combreg')
}
else {
	local a1=0
	}
    
	
	rename bs bs_original
	rename bs_sebs bs
	rename ones_sebs constant
	rename ones pub_bias
	
	
    noisily: display "EK regression: "

if `a1'>`sebs_min' & `a1'<`sebs_max' {
    gen sebs_a1=sebs-`a1' if sebs>`a1'
	replace sebs_a1=0 if sebs<=`a1'
	gen pubbias=sebs_a1/sebs
	noisily regress bs constant pubbias, noc
	local b0_ek=_b[constant]
	local b1_ek=_b[pubbias]
	local sd0_ek=_se[constant]
	local sd1_ek=_se[pubbias]
}
else if `a1'<`sebs_min' {
    noisily regress bs constant pub_bias, noc
	local b0_ek=_b[constant]
	local b1_ek=_b[pub_bias]
	local sd0_ek=_se[constant]
	local sd1_ek=_se[pub_bias]
}
else if `a1'>`sebs_max' {
    noisily regress bs constant, noc
	local b0_ek=_b[constant]
	local sd0_ek=_se[constant]	
}
noisily: display "EK's mean effect estimate (alpha1) and standard error:"
noisily: di `b0_ek' 
noisily: di `sd0_ek' 
noisily: display "EK's publication bias estimate (delta) and standard error:"
noisily: di `b1_ek' 
noisily: di `sd1_ek' 

log close
}

*SE:
quietly {

clear 

import excel "ek-se.xlsx"
rename A bs
rename B sebs

log using kink_se.log, text replace
 
gen ones=1
   
sum
local M=r(N)
sum sebs
local sebs_min=r(min)
local sebs_max=r(max)
  
gen sebs2=sebs^2
gen wis=ones/sebs2
gen bs_sebs=bs/sebs
gen ones_sebs=ones/sebs

gen bswis=bs*wis
sum wis
local wis_sum=r(sum)


* FAT-PET
regress bs_sebs ones_sebs ones,noc
local pet=_b[ones_sebs]
local t1_linreg = (_b[ones_sebs]/_se[ones_sebs])
local b_lin=_b[ones_sebs]
local Q1_lin = e(rss)
di `t1_linreg'
local abs_t1_linreg = abs(`t1_linreg')
di `abs_t1_linreg'


* PEESE
regress bs_sebs ones_sebs sebs,noc
local peese=_b[ones_sebs]
local b_sq=_b[ones_sebs]
local Q1_sq = e(rss)
di `Q1_sq'
 

* FAT-PET-PEESE

if `abs_t1_linreg' > invt(`M-2', 0.975) {
    local combreg=`b_sq'
	local Q1=`Q1_sq'
	}
else {
    local combreg=`b_lin'
	local Q1=`Q1_lin'
}

* estimation of random effects variance component
local sigh2hat=max(0,`M'*((`Q1'/(`M'-e(df_m)-1))-1)/`wis_sum') 
local sighhat=sqrt(`sigh2hat') 


* Cutoff value for EK
if `combreg'>1.96*`sighhat' {
    local a1=(`combreg'-1.96*`sighhat')*(`combreg'+1.96*`sighhat')/(2*1.96*`combreg')
}
else {
	local a1=0
	}
    
	
	rename bs bs_original
	rename bs_sebs bs
	rename ones_sebs constant
	rename ones pub_bias
	
	
    noisily: display "EK regression: "

if `a1'>`sebs_min' & `a1'<`sebs_max' {
    gen sebs_a1=sebs-`a1' if sebs>`a1'
	replace sebs_a1=0 if sebs<=`a1'
	gen pubbias=sebs_a1/sebs
	noisily regress bs constant pubbias, noc
	local b0_ek=_b[constant]
	local b1_ek=_b[pubbias]
	local sd0_ek=_se[constant]
	local sd1_ek=_se[pubbias]
}
else if `a1'<`sebs_min' {
    noisily regress bs constant pub_bias, noc
	local b0_ek=_b[constant]
	local b1_ek=_b[pub_bias]
	local sd0_ek=_se[constant]
	local sd1_ek=_se[pub_bias]
}
else if `a1'>`sebs_max' {
    noisily regress bs constant, noc
	local b0_ek=_b[constant]
	local sd0_ek=_se[constant]	
}
noisily: display "EK's mean effect estimate (alpha1) and standard error:"
noisily: di `b0_ek' 
noisily: di `sd0_ek' 
noisily: display "EK's publication bias estimate (delta) and standard error:"
noisily: di `b1_ek' 
noisily: di `sd1_ek' 

log close
}

log on
*Stem-based method - Furukawa 2019 - Switch to the R-part of the code

*SE Combined:
*            estimate        se            sd of total heterogeneity    n_stem  n_iteration  multiple    % info used
*            0.1873971       0.1120905     0.2238279                    4       3            0           0.1461126


*SE:
*            estimate        se            sd of total heterogeneity    n_stem  n_iteration  multiple    % info used
*            0.1695432	     0.1080379	   0.186673	                    3	    3	         0	         0.1590264


********************************************************************************
* Publication bias - p-uniform* (van Aert & van Assen, 2019) - code for Stata & R
********************************************************************************

*gen tstatistics = frisch_win/se_comb_win
gen variance_comb_win = se_comb_win*se_comb_win

*median
bysort idstudy: egen variancemed = median(variance_comb_win)
*bysort idstudy: egen tstat_med = median(tstatistics)
bysort idstudy: egen frischwinmed = median(frisch_win)
bysort idstudy: egen secomwinbmed = median(se_comb_win)
bysort idstudy: egen tstatcombwinmed = median(tstat_comb_win)

preserve
collapse  (lastnm) frischwinmed variancemed secomwinbmed tstatcombwinmed  (p50) nobs_med=no_obs, by(idstudy)
save "pcurve_med.dta", replace
restore

********************************************************************************
*DATA PREPARATION FOR BMA
********************************************************************************

*Baseline - combined
preserve
order idstudy frisch_win se_comb_win ln_timespan  monthly quarterly annual  prime nearretirement female male married single income industry usa nusa indivlab micro macro quasi_exp ols probit nonpar_sim sls_iv quantile lnpubyear top lnycite cite_google byproduct 
drop paper	published	idcoeff	frisch	se	no_obs	est_per_study	year	start	
drop end timespan malefemale	 pooled_crosec	panel biannual  wealth wls mle daily  pub_year ln_cite
drop empr	study_mean	study_se	prec	prec2	tstat  pub_year_dif 
drop invperstudy	se_win	tstat_win	prec_win	prec2_win	se_comb	prec_comb	prec2_comb	lnobs invsqrtnobs sqrtnobs lnprec lnprec_comb	
drop tstat_comb se2_comb_win tstat_comb_win	prec_comb_win	prec2_comb_win	prec2_comb_win fmean	damean	momean	prmean nrmean almean nprmean
drop qumean	anmean	usmean	nusmean	mamean	femean	quasmean	nquasmean	macmean	micmean fmed
saveold bma_base_comb, replace
restore

*Weighted by sqrt(invperstudy) - combined 
preserve
local rhsvars frisch_win se_comb_win ln_timespan  monthly quarterly annual prime nearretirement female male married single  income industry usa nusa indivlab micro macro quasi_exp ols probit nonpar_sim sls_iv quantile lnpubyear top lnycite cite_google byproduct 
foreach x of varlist `rhsvars' {
replace `x' = `x'*sqrt(invperstudy)
}
order frisch_win se_comb_win ln_timespan  monthly quarterly annual  prime nearretirement female male married single  income industry usa nusa indivlab micro macro quasi_exp ols probit  nonpar_sim sls_iv quantile lnpubyear top lnycite cite_google byproduct 
drop paper	idstudy	published	idcoeff	frisch	se	no_obs	est_per_study	year	start	
drop end timespan malefemale	 pooled_crosec	panel biannual wealth wls mle daily pub_year ln_cite
drop empr study_mean	study_se	prec	prec2	tstat  pub_year_dif
drop invperstudy	se_win	tstat_win	prec_win	prec2_win	se_comb	prec_comb	prec2_comb	lnprec lnobs invsqrtnobs sqrtnobs lnprec_comb
drop tstat_comb se2_comb_win	tstat_comb_win	prec_comb_win	prec2_comb_win	fmean	damean	momean	prmean nrmean almean nprmean
drop qumean	anmean	usmean	nusmean	mamean	femean	quasmean	nquasmean	macmean	micmean fmed
saveold bma_ps_comb, replace
restore 

*Weighted by 1/SE - combined 
preserve
local rhsvars frisch_win ln_timespan  monthly quarterly annual prime nearretirement female male married single income industry usa nusa indivlab micro macro quasi_exp ols probit nonpar_sim sls_iv quantile lnpubyear top lnycite cite_google byproduct 
foreach x of varlist `rhsvars' {
replace `x' = (`x'/se_comb_win)
}
order frisch_win se_comb_win ln_timespan  monthly quarterly annual prime nearretirement female male married single income industry usa nusa indivlab micro macro quasi_exp ols probit nonpar_sim sls_iv quantile lnpubyear top lnycite cite_google byproduct 
drop paper idstudy	published	idcoeff	frisch	se	no_obs	est_per_study	year	start	
drop end timespan malefemale	pooled_crosec	panel biannual wealth wls mle daily pub_year ln_cite
drop empr	study_mean	study_se	prec	prec2	tstat 	pub_year_dif
drop invperstudy	se_win	tstat_win	prec_win	prec2_win	se_comb	prec_comb	prec2_comb lnprec lnobs invsqrtnobs sqrtnobs lnprec_comb	
drop tstat_comb se_comb_win se2_comb_win	tstat_comb_win	prec_comb_win	prec2_comb_win	fmean	damean	momean	prmean nrmean almean nprmean
drop qumean	anmean	usmean	nusmean	mamean	femean	quasmean	nquasmean	macmean	micmean fmed
saveold bma_se_comb, replace
restore 



********************************************************************************
* Now switch to the R-PART OF THE CODE: BMA
********************************************************************************

*************************FREQUENTIST CHECK OF BMA*******************************
********************************************************************************

* SE combined - regressors with pip > 80%
sum  se_comb_win prime nearretirement male industry macro quasi_exp probit  lnycite
correlate se_comb_win prime nearretirement male industry macro quasi_exp probit lnycite
collin se_comb_win prime nearretirement male industry macro quasi_exp probit lnycite

*UIP prior

eststo: reg frisch_win se_comb_win prime nearretirement male industry macro quasi_exp probit lnycite, cluster(idstudy)

estout, style(tex) cells("b se t p")

eststo clear 

* SE non-combined - regressors with pip > 80%
sum se_win nearretirement  industry macro indivlab probit lnpubyear top if se_win!=.
correlate se_win nearretirement  industry macro indivlab probit lnpubyear top
collin se_win nearretirement  industry macro indivlab probit lnpubyear top 

*UIP prior

eststo: reg frisch_win se_win nearretirement  industry macro indivlab probit lnpubyear top, cluster(idstudy)

estout, style(tex) cells("b se t p")

eststo clear 

/*esttab est1 using freqcheck_comb.tex, replace title(Frequentist check /// \
	\label{tab: freqcomb})  mtitles("Dep Var" "Coef" "SE" "t" ) /// \
	star (\sym{*} 0.10 \sym{**} 0.05 \sym{***} 0.01) /// \
	label nonumber nogaps width(1\\hsize)
eststo clear 
*/

********************************BEST PRACTICE***********************************
********************************************************************************
sum frisch_win se_comb_win ln_timespan monthly quarterly prime nearretirement female male married single income industry usa indivlab macro quasi_exp probit nonpar_sim sls_iv lnpubyear top lnycite byproduct

ivreg2 frisch_win se_comb_win ln_timespan monthly quarterly prime nearretirement female male married single income industry usa indivlab macro quasi_exp probit nonpar_sim sls_iv lnpubyear top lnycite byproduct , cluster (idstudy)


***Subjective best practice***

*base
lincom _cons + 0*se_comb_win + 3.7612*ln_timespan + 0*monthly + 0*quarterly + 0*prime + 0*nearretirement + 0*female + 0*male + 0*married + 0*single + 0*income + 0*industry + .670816*usa + 0*indivlab + 0*macro + 1*quasi_exp + 0.0525588*probit + 0.3679115*nonpar_sim + 1*sls_iv + 3.583519*lnpubyear + 1*top + 1.754619*lnycite + 0*byproduct

*nearretirement
lincom _cons + 0*se_comb_win + 3.7612*ln_timespan + 0*monthly + 0*quarterly + 0*prime + 1*nearretirement + 0*female + 0*male + 0*married + 0*single + 0*income + 0*industry + .670816*usa + 0*indivlab + 0*macro + 1*quasi_exp + 0.0525588*probit + 0.3679115*nonpar_sim + 1*sls_iv + 3.583519*lnpubyear + 1*top + 1.754619*lnycite + 0*byproduct

*female
lincom _cons + 0*se_comb_win + 3.7612*ln_timespan + 0*monthly + 0*quarterly + 0*prime + 0*nearretirement + 1*female + 0*male + 0*married + 0*single + 0*income + 0*industry + .670816*usa + 0*indivlab + 0*macro + 1*quasi_exp + 0.0525588*probit + 0.3679115*nonpar_sim + 1*sls_iv + 3.583519*lnpubyear + 1*top + 1.754619*lnycite + 0*byproduct


***Blundell et al. (2016a)***

*base

lincom _cons + 0*se_comb_win + 2.89*ln_timespan + 0*monthly + 0*quarterly + 0*prime + 0*nearretirement + 0*female + 0*male + 0*married + 0*single + 0*income + 0*industry + 0*usa + 0*indivlab + 0*macro + 1*quasi_exp + 0*probit + 1*nonpar_sim + 0*sls_iv + 3.46*lnpubyear + 1*top + 1.754619*lnycite + 0*byproduct

*nearretirement

lincom _cons + 0*se_comb_win + 2.89*ln_timespan + 0*monthly + 0*quarterly + 0*prime + 1*nearretirement + 0*female + 0*male + 0*married + 0*single + 0*income + 0*industry + 0*usa + 0*indivlab + 0*macro + 1*quasi_exp + 0*probit + 1*nonpar_sim + 0*sls_iv + 3.46*lnpubyear + 1*top + 1.754619*lnycite + 0*byproduct

*female

lincom _cons + 0*se_comb_win + 2.89*ln_timespan + 0*monthly + 0*quarterly + 0*prime + 0*nearretirement + 1*female + 0*male + 0*married + 0*single + 0*income + 0*industry + 0*usa + 0*indivlab + 0*macro + 1*quasi_exp + 0*probit + 1*nonpar_sim + 0*sls_iv + 3.46*lnpubyear + 1*top + 1.754619*lnycite + 0*byproduct

*log close	
*exit, clear
